# Requirements

Python 3.6.7 (and up)
Redis 5 (and up)
Postgres 11 (and up)

General requirements
```eval_rst
.. include:: ../../requirements.txt
   :literal:
```

Development requirements
```eval_rst
.. include:: ../../requirements-dev.txt
   :literal:
```